get_client

Function get_client 

pub fn get_client(config: &CommitConfig) -> &'static Client
Get (or create) the shared HTTP client with timeouts from config.

The first call initializes the client with the given config’s timeouts; subsequent calls reuse the same client regardless of config values.