Module git

Module git 

Re-exports

pub use self::git_push as push;

Structs

StylePatterns
Quantified style patterns extracted from commit history
TempGitIndex
A temporary Git index file under .git/llm-git/.

Functions

append_signoff_trailer
check_working_tree_clean
Check if working directory is clean
commit_tree
create_backup_branch
Create timestamped backup branch
current_head_ref
ensure_git_repo
Ensure the provided directory is inside a git work tree.
extract_style_patterns
Extract style patterns from commit history
get_commit_list
Get list of commit hashes to rewrite (in chronological order)
get_commit_metadata
Extract complete metadata for a commit (for rewriting)
get_common_scopes
Extract common scopes from git history by parsing commit messages
get_compose_diff
get_compose_stat
get_git_diff
Get git diff based on the specified mode
get_git_dir
get_git_numstat
get_git_stat
Get git diff –stat to show file-level changes summary
get_head_hash
Get the current HEAD commit hash
get_recent_commits
Get recent commit messages for style consistency (last N commits)
git_command
git_command_with_index
git_commit
Execute git commit with the given message
git_push
Execute git push
init_git_command_settings
read_tree_into_index
reset_mixed_to
rewrite_history
Rewrite git history with new commit messages
update_ref_checked
write_index_tree
write_real_index_tree