ensure_git_repo

Function ensure_git_repo 

pub fn ensure_git_repo(dir: &str) -> Result<()>
Ensure the provided directory is inside a git work tree.

Errors

Returns an error when the directory is not part of a git repository.